@@ -11,9 +11,7 @@
 #include <glib.h>
 #include <string.h>
 
-#include <libintl.h>
-#define _(x) gettext(x)
-#include <locale.h>
+#include <glib/gi18n.h>
 
 #include "rdpfile.h"
 #include "support.h"
@@ -27,29 +25,32 @@ static void tsc_print_version ();
 int
 main (int argc, char *argv[])
 {
-  gint i;
-  gchar *rdp_file_name = "";
-  gchar *home = tsc_home_path ();
-  gchar *tsc_default = g_build_path ("/", home, "default.tsc", NULL);
-  gchar *tsc_last = g_build_path ("/", home, "last.tsc", NULL);
-  rdp_file *rdp = NULL;
-
-  gtk_set_locale ();
-  gtk_init (&argc, &argv);
+  gint     i;
+  gchar    *rdp_file_name = "";
+  rdp_file *rdp           = NULL;
+  gchar *home, *tsc_default, *tsc_last;
 
   #ifdef TSCLIENT_DEBUG
   printf ("debugging messages are on\n");
   #endif
 
-  setlocale (LC_ALL, "");
   bindtextdomain (PACKAGE, PACKAGE_LOCALE_DIR);
   bind_textdomain_codeset (PACKAGE, "UTF-8");
   textdomain (PACKAGE);
 
+  gtk_init (&argc, &argv);
+
   #ifdef TSCLIENT_DEBUG
   printf ("gtk default language: %s\n", gtk_get_default_language ());
   #endif
 
+  home        = tsc_home_path ();
+  tsc_default = g_build_path ("/", home, "default.tsc", NULL);
+  tsc_last    = g_build_path ("/", home, "last.tsc", NULL);
+
+  g_free (home);
+
+
   add_pixmap_directory (PACKAGE_DATA_DIR "/pixmaps/tsclient/");
 
   // make sure our dirs & files exist
@@ -109,7 +110,6 @@ main (int argc, char *argv[])
 
   g_free (tsc_last);
   g_free (tsc_default);
-  g_free (home);
 
   gtk_main ();
   return 0;
