@@ -60,6 +60,7 @@ int rdp_file_init (rdp_file *rdp_in)
   rdp->keyboardhook = 0;
   rdp->no_motion_events = 0;
   rdp->password = "";
+  rdp->win_password = "";
   rdp->progman_group = "";
   rdp->protocol = 0;
   rdp->proto_file = "";
@@ -215,6 +216,7 @@ int rdp_file_save (rdp_file *rdp_in, const char *fqpath)
   buffer = g_strconcat (buffer, "keyboardhook:i:", g_strdup_printf("%d",rdp->keyboardhook), "\r\n", NULL);
   buffer = g_strconcat (buffer, "no motion events:i:", g_strdup_printf("%d",rdp->no_motion_events), "\r\n", NULL);
   buffer = g_strconcat (buffer, "password:b:", rdp->password, "\r\n", NULL);
+  buffer = g_strconcat (buffer, "password 51:b:", rdp->win_password, "\r\n", NULL);
   buffer = g_strconcat (buffer, "progman group:s:", rdp->progman_group, "\r\n", NULL);
   buffer = g_strconcat (buffer, "protocol:i:", g_strdup_printf("%d",rdp->protocol), "\r\n", NULL);
   buffer = g_strconcat (buffer, "protocol file:s:", rdp->proto_file, "\r\n", NULL);
@@ -290,6 +292,13 @@ int rdp_file_set_screen (rdp_file *rdp_in, GtkWidget *main_window)
   gtk_editable_delete_text ((GtkEditable*) widget, 0, -1);
   gtk_editable_insert_text((GtkEditable*) widget, (gchar *)rdp->username, strlen(rdp->username), &pos);
 
+  widget = lookup_widget (main_window, "txtPassword");
+  gtk_editable_delete_text ((GtkEditable*) widget, 0, -1);
+  gtk_editable_insert_text((GtkEditable*) widget, (gchar *)rdp->password, strlen(rdp->password), &pos);
+
+  /* win password (oh, ugly)*/
+  g_object_set_data (G_OBJECT (main_window), "win_password", rdp->win_password);
+
   widget = lookup_widget (main_window, "txtDomain");
   gtk_editable_delete_text ((GtkEditable*) widget, 0, -1);
   gtk_editable_insert_text((GtkEditable*) widget, (gchar *)rdp->domain, strlen(rdp->domain), &pos);
@@ -501,10 +510,6 @@ int rdp_file_set_screen (rdp_file *rdp_in, GtkWidget *main_window)
     break;
   } */
       
-  // clear out the password - it can not be retreived as it is encrypted in rdp files.  :-(
-  widget = lookup_widget (main_window, "txtPassword");
-  gtk_editable_delete_text ((GtkEditable*) widget, 0, -1);
-
   tsc_set_protocol_widgets (main_window, rdp->protocol);
   
   // end if and drop out
@@ -534,7 +539,7 @@ int rdp_file_get_screen (rdp_file *rdp_in, GtkWidget *main_window)
   
   widget = lookup_widget (main_window, "txtComputer");
   value = gtk_editable_get_chars ((GtkEditable*) widget, 0, -1);
-  if (value) rdp->full_address = g_strdup (value);
+  if (value) rdp->full_address = value;
 
   widget = lookup_widget (main_window, "optProtocol");
   switch (gtk_option_menu_get_history (GTK_OPTION_MENU (widget))) {
@@ -556,23 +561,30 @@ int rdp_file_get_screen (rdp_file *rdp_in, GtkWidget *main_window)
   
   widget = lookup_widget (main_window, "txtUsername");
   value = gtk_editable_get_chars ((GtkEditable*) widget, 0, -1);
-  if (value) rdp->username = g_strdup (value);
+  if (value) rdp->username = value;
+
+  widget = lookup_widget (main_window, "txtPassword");
+  value = gtk_editable_get_chars ((GtkEditable*) widget, 0, -1);
+  if (value) rdp->password = value;
+
+  /* win password (oh, ugly)*/
+  rdp->win_password = g_object_get_data (G_OBJECT (main_window), "win_password");
   
   widget = lookup_widget (main_window, "txtDomain");
   value = gtk_editable_get_chars ((GtkEditable*) widget, 0, -1);
-  if (value) rdp->domain = g_strdup (value);
+  if (value) rdp->domain = value;
   
   widget = lookup_widget (main_window, "txtClientHostname");
   value = gtk_editable_get_chars ((GtkEditable*) widget, 0, -1);
-  if (value) rdp->client_hostname = g_strdup (value);
+  if (value) rdp->client_hostname = value;
     
   widget = lookup_widget (main_window, "txtProtoFile");
   value = gtk_editable_get_chars ((GtkEditable*) widget, 0, -1);
-  if (value) rdp->proto_file = g_strdup (value);
+  if (value) rdp->proto_file = value;
   
   widget = lookup_widget (main_window, "txtKeyboardLang");
   value = gtk_editable_get_chars ((GtkEditable*) widget, 0, -1);
-  if (value) rdp->keyboard_language = g_strdup (value);
+  if (value) rdp->keyboard_language = value;
 
   widget = lookup_widget (main_window, "chkAltFullSwitch");
   if (gtk_toggle_button_get_active ((GtkToggleButton*)widget))
@@ -682,11 +694,11 @@ int rdp_file_get_screen (rdp_file *rdp_in, GtkWidget *main_window)
 
   widget = lookup_widget (main_window, "txtProgramPath");
   value = gtk_editable_get_chars ((GtkEditable*) widget, 0, -1);
-  if (value) rdp->alternate_shell = g_strdup (value);
+  if (value) rdp->alternate_shell =  value;
   
   widget = lookup_widget (main_window, "txtStartFolder");
   value = gtk_editable_get_chars ((GtkEditable*) widget, 0, -1);
-  if (value) rdp->shell_working_directory = g_strdup (value);
+  if (value) rdp->shell_working_directory = value;
   
 
   widget = lookup_widget (main_window, "chkBitmapCache");
@@ -746,9 +758,6 @@ int rdp_file_get_screen (rdp_file *rdp_in, GtkWidget *main_window)
   else
     rdp->attach_to_console = 0;
 
-  // clean up
-  g_free (value);
-
   return 0;
 
 }
@@ -868,6 +877,9 @@ int rdp_file_set_from_line (rdp_file *rdp_in, const char *str_in)
     if (strcmp(key, "password") == 0) {
       rdp->password = g_strdup(value);
     }
+    if (strcmp(key, "password 51") == 0) {
+      rdp->win_password = g_strdup(value);
+    }
     if (strcmp(key, "progman group") == 0) {
       rdp->progman_group = g_strdup(value);
     }
@@ -923,56 +935,33 @@ int rdp_file_set_from_line (rdp_file *rdp_in, const char *str_in)
  
 int rdp_load_profile_launcher (GtkWidget *main_window)
 {
-  GtkWidget *box;
   GtkWidget *opt;
-  GtkWidget *mnu;
-  GtkWidget *mi;
   GSList    *lptr = NULL;
-  gchar     *name = NULL;
-  gint cnt, ret;
+  gint      cnt, ret;
   
   #ifdef TSCLIENT_DEBUG
   printf ("rdp_load_profile_launcher\n");
   #endif
 
-  box = lookup_widget (main_window, "hbxProfileLauncher");
   opt = lookup_widget (main_window, "optProfileLauncher");
-
   ret = rdp_files_to_list (&lptr);
   cnt = 0;
-  mnu = gtk_menu_new ();
+
   while (lptr) {
-    name = g_strdup (lptr->data);
-    mi = gtk_menu_item_new_with_label (name);
-    g_signal_connect (G_OBJECT (mi), "activate", G_CALLBACK (tsc_quick_pick_activate), name);
-    gtk_widget_ref (GTK_WIDGET (mi));
-    gtk_container_add (GTK_CONTAINER (mnu), mi);
-    //gtk_menu_shell_append ((GtkMenuShell *)mnu, mi);
-    /* move forward */
+    gtk_combo_box_append_text (GTK_COMBO_BOX(opt), lptr->data);
+
     g_free (lptr->data);
     lptr = lptr->next;
     cnt++;
   }
-  g_slist_free (lptr);
-  g_free (name);
-  g_object_ref (G_OBJECT (mnu));
 
-  if (cnt < 1) {
-    //gtk_widget_hide_all (box);
-    gtk_widget_set_sensitive (opt, FALSE);
-  } else {
-    //gtk_widget_show_all (box);
-    gtk_widget_show_all (mnu);
-    gtk_widget_set_sensitive (opt, TRUE);
-    gtk_option_menu_set_menu ((GtkOptionMenu*)opt, mnu);
-  }
+  g_slist_free (lptr);
+  gtk_widget_set_sensitive (opt, cnt > 0);
 
   /* complete successfully */
   return 0;
-  
 }
 
-
 /***************************************
 *                                      *
 *   read_dir_list                      *
