@@ -12,9 +12,9 @@
 #include <gtk/gtk.h>
 #include <gdk/gdk.h>
 #include <glib.h>
+#include <glib/gprintf.h>
 
-#include <libintl.h>
-#define _(x) gettext(x)
+#include <glib/gi18n.h>
 
 #include <sys/types.h> 
 #include <sys/stat.h> 
@@ -43,19 +43,26 @@ GtkWidget* lookup_widget (GtkWidget *widget, const gchar *widget_name) {
   GtkWidget *parent, *found_widget;
 
   for (;;) {
+
     if (GTK_IS_MENU (widget))
       parent = gtk_menu_get_attach_widget (GTK_MENU (widget));
     else
       parent = widget->parent;
+
     if (!parent)
-      parent = gtk_object_get_data (GTK_OBJECT (widget), "GladeParentKey");
+      parent = g_object_get_data (G_OBJECT (widget), "GladeParentKey");
+
     if (parent == NULL)
       break;
+
     widget = parent;
   }
-  found_widget = (GtkWidget*) gtk_object_get_data (GTK_OBJECT (widget), widget_name);
+
+  found_widget = (GtkWidget*) g_object_get_data (G_OBJECT (widget), widget_name);
+
   if (!found_widget)
     g_warning ("Widget not found: %s", widget_name);
+
   return found_widget;
 }
 
@@ -369,7 +376,7 @@ int tsc_launch_remote (rdp_file *rdp_in, int launch_async, gchar** error)
       sprintf(buffer, cmd);
       c_argv[c_argc++] = g_strdup (buffer);
 
-      sprintf(buffer, "-T%s - Terminal Server Client", rdp->full_address);
+      sprintf(buffer, "-T%s - %s", rdp->full_address, _("Terminal Server Client"));
       c_argv[c_argc++] = g_strdup (buffer);
       
       // full window mode - use all opts    
@@ -462,6 +469,10 @@ int tsc_launch_remote (rdp_file *rdp_in, int launch_async, gchar** error)
         c_argv[c_argc++] = g_strdup (buffer);
       }
 
+      /*  clipboard feature, rdesktop 1.5 */
+      sprintf(buffer, "-rclipboard:PRIMARYCLIPBOARD");
+      c_argv[c_argc++] = g_strdup (buffer);
+
       if (rdp->bitmapcachepersistenable == 1) {
         sprintf(buffer, "-b");
         c_argv[c_argc++] = g_strdup (buffer);
@@ -540,7 +551,7 @@ int tsc_launch_remote (rdp_file *rdp_in, int launch_async, gchar** error)
       c_argv[c_argc++] = g_strdup (buffer);
 
       if (rdp->screen_mode_id == 2) {
-        sprintf(buffer, "-FullScreen");
+        sprintf(buffer, "-fullscreen");
         c_argv[c_argc++] = g_strdup (buffer);
       } else {
         switch (rdp->desktopwidth) {
@@ -837,7 +848,7 @@ int tsc_launch_remote (rdp_file *rdp_in, int launch_async, gchar** error)
 	  *error = g_strdup(_("Failed to spawn.\nPlease verify your installation."));
 	}
       }
-      if (std_err && strlen(std_err)) {
+      if (exit_stat && std_err && strlen(std_err)) {
 	g_warning ("\n%s\n", std_err);
 	if(error) {
 	  *error = g_strdup((gchar*)std_err);
@@ -898,7 +909,7 @@ void tsc_connect_error (rdp_file * rdp, const gchar* error)
   gint responce, c_id;
   
 #ifdef TSCLIENT_DEBUG
-  printf ("tsc_error_message\n");
+  printf ("tsc_connect_error\n");
 #endif
   
   if (!error)
@@ -1004,50 +1015,54 @@ void tsc_error_message (gchar *message)
 
 void tsc_about_dialog ()
 {
-  static GtkWidget *about = NULL;
   const gchar *name      = _("Terminal Server Client");
-  const gchar *version   = VERSION;
-  const gchar *copyright = "(C) 2002-2006 Erick Woods";
+  const gchar *copyright = "(C) 2002-2006 Erick Woods\n"
+			   "(C) 2007 Jonh Wendell";
   const gchar *website = "http://www.gnomepro.com/tsclient/";
-  const gchar *authors[] = { "Erick Woods <erick@gnomepro.com>", "Kyle Davis <kyle@gnomeuser.org>", NULL };
-  const gchar *artists[] = { "Erick Woods <erick@gnomepro.com>", "Jakub Steiner", NULL };
-  //const gchar *documenters[] = { NULL };
-  //const gchar *translator_credits = NULL;
-  GdkPixbuf *logo = create_pixbuf ("tsclient.png");
 
-  const gchar *license = \
+  const gchar *authors[] = {
+			   "Erick Woods <erick@gnomepro.com>",
+			   "Kyle Davis <kyle@gnomeuser.org>",
+			   "Jonh Wendell <wendell@bani.com.br>",
+			   NULL };
+
+  const gchar *artists[] = {
+			   "Erick Woods <erick@gnomepro.com>",
+			   "Jakub Steiner",
+			   NULL };
+
+  const gchar *license = _(\
     "Terminal Server Client is licensed under the \n" \
-    "GNU General Public License (GPL)\n<http://www.gnu.org/licenses/gpl.html>";
+    "GNU General Public License (GPL)\n<http://www.gnu.org/licenses/gpl.html>");
 
   const gchar *comments = \
-    "Terminal Server Client is a frontend for \nrdesktop, vncviewer, wfica and xnest.";
+    _("Terminal Server Client is a frontend for \nrdesktop, vncviewer, wfica and xnest.");
   
-  if (about) {
-    gtk_window_present (GTK_WINDOW (about));
-    return;
-  }
-  
-  about = gtk_about_dialog_new ();
-  gtk_about_dialog_set_name (GTK_ABOUT_DIALOG(about), name);
-  gtk_about_dialog_set_version (GTK_ABOUT_DIALOG(about), version);
-  gtk_about_dialog_set_copyright (GTK_ABOUT_DIALOG(about), copyright);
-  gtk_about_dialog_set_comments (GTK_ABOUT_DIALOG(about), comments);
-  gtk_about_dialog_set_website (GTK_ABOUT_DIALOG(about), website);
-  gtk_about_dialog_set_authors (GTK_ABOUT_DIALOG(about), authors);
-  gtk_about_dialog_set_license (GTK_ABOUT_DIALOG(about), license);
-  gtk_about_dialog_set_artists (GTK_ABOUT_DIALOG(about), artists);
-  gtk_about_dialog_set_logo (GTK_ABOUT_DIALOG(about), logo);
-  
-  //gtk_window_set_wmclass (GTK_WINDOW (about), "terminal server client", "Terminal Server Client");
-  g_signal_connect (G_OBJECT (about), "destroy", G_CALLBACK (gtk_widget_destroyed), &about);
-  gtk_widget_show_all (about);  
-  return;
+  gchar *translators;
+  /* Translators comment: put your own name here to appear in the about dialog. */
+  translators = _("translator-credits");
+
+  if (!strcmp (translators, "translator-credits"))
+    translators = NULL;
+
+  gtk_show_about_dialog (NULL,
+			 "name",               name,
+			 "comments",           comments,
+			 "version",            VERSION,
+			 "license",            license,
+			 "authors",            authors,
+			 "translator-credits", translators,
+			 "logo-icon-name",     "tsclient",
+			 "copyright",		copyright,
+			 "website",		website,
+			 "artists",		artists,
+			 NULL);
 }
 
 
-void tsc_quick_pick_activate (GtkMenuItem *menuitem, gpointer user_data)
+void tsc_quick_pick_activate (GtkComboBox *widget, gpointer user_data)
 {
-  gchar *file_name;
+  gchar *file_name, *rdp_name;
   gchar *home = tsc_home_path ();
   rdp_file *rdp = NULL;
 
@@ -1055,8 +1070,14 @@ void tsc_quick_pick_activate (GtkMenuItem *menuitem, gpointer user_data)
   printf ("tsc_quick_pick_activate\n");
   #endif
 
+  /* Do nothing if it's the first element (just a instruction)*/
+  if (gtk_combo_box_get_active(widget) == 0)
+    return;
+
+  rdp_name = gtk_combo_box_get_active_text (widget);
+
   // build path to file
-  file_name = g_build_path ("/", home, (const gchar *)user_data, NULL);
+  file_name = g_build_path ("/", home, (const gchar *)rdp_name, NULL);
   // check for file in ~/
   if (g_file_test (file_name, G_FILE_TEST_EXISTS)) {
     // exists, load it
@@ -1075,10 +1096,13 @@ void tsc_quick_pick_activate (GtkMenuItem *menuitem, gpointer user_data)
   g_free (rdp);
   g_free (file_name);
   g_free (home);
+  g_free (rdp_name);
+
+  gtk_combo_box_set_active (widget, 0);
+
   return;
 }
 
-
 void
 tsc_set_protocol_widgets (GtkWidget *main_win, gint protocol)
 {
