@@ -17,7 +17,7 @@
 #define MAX_ARGV_LEN 255
 
 #define HOOKUP_OBJECT(component,widget,name) \
-  gtk_object_set_data_full (GTK_OBJECT (component), name, \
+  g_object_set_data_full (G_OBJECT (component), name, \
     gtk_widget_ref (widget), (GtkDestroyNotify) gtk_widget_unref)
 
 /*
@@ -52,6 +52,6 @@ void tsc_error_message (gchar *message);
 
 void tsc_about_dialog ();
 
-void tsc_quick_pick_activate (GtkMenuItem *menuitem, gpointer user_data);
+void tsc_quick_pick_activate (GtkComboBox *widget, gpointer user_data);
 
 void tsc_set_protocol_widgets (GtkWidget *main_win, gint protocol);
